==> huaweicloudsdkdgc-3.1.138-py2.py3-none-any.whl: huaweicloudsdkdgc/v1/model/delete_req.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DeleteReq:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'approvers': 'list[JobApprover]'
    }

    attribute_map = {
        'approvers': 'approvers'
    }

    def __init__(self, approvers=None):
        """DeleteReq

        The model defined in huaweicloud sdk

        :param approvers: 在开启审批开关后，需要填写该字段，表示作业（或脚本）审批人。
        :type approvers: list[:class:`huaweicloudsdkdgc.v1.JobApprover`]
        """
        
        

        self._approvers = None
        self.discriminator = None

        if approvers is not None:
            self.approvers = approvers

    @property
    def approvers(self):
        """Gets the approvers of this DeleteReq.

        在开启审批开关后，需要填写该字段，表示作业（或脚本）审批人。

        :return: The approvers of this DeleteReq.
        :rtype: list[:class:`huaweicloudsdkdgc.v1.JobApprover`]
        """
        return self._approvers

    @approvers.setter
    def approvers(self, approvers):
        """Sets the approvers of this DeleteReq.

        在开启审批开关后，需要填写该字段，表示作业（或脚本）审批人。

        :param approvers: The approvers of this DeleteReq.
        :type approvers: list[:class:`huaweicloudsdkdgc.v1.JobApprover`]
        """
        self._approvers = approvers

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeleteReq):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkdgc-3.1.145-py2.py3-none-any.whl: huaweicloudsdkdgc/v1/model/delete_req.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DeleteReq:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'approvers': 'list[JobApprover]'
    }

    attribute_map = {
        'approvers': 'approvers'
    }

    def __init__(self, approvers=None):
        r"""DeleteReq

        The model defined in huaweicloud sdk

        :param approvers: 在开启审批开关后，需要填写该字段，表示作业（或脚本）审批人。
        :type approvers: list[:class:`huaweicloudsdkdgc.v1.JobApprover`]
        """
        
        

        self._approvers = None
        self.discriminator = None

        if approvers is not None:
            self.approvers = approvers

    @property
    def approvers(self):
        r"""Gets the approvers of this DeleteReq.

        在开启审批开关后，需要填写该字段，表示作业（或脚本）审批人。

        :return: The approvers of this DeleteReq.
        :rtype: list[:class:`huaweicloudsdkdgc.v1.JobApprover`]
        """
        return self._approvers

    @approvers.setter
    def approvers(self, approvers):
        r"""Sets the approvers of this DeleteReq.

        在开启审批开关后，需要填写该字段，表示作业（或脚本）审批人。

        :param approvers: The approvers of this DeleteReq.
        :type approvers: list[:class:`huaweicloudsdkdgc.v1.JobApprover`]
        """
        self._approvers = approvers

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeleteReq):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
